summaryrefslogtreecommitdiffstats
path: root/qtsharp/src/examples/tutorials
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 15:55:57 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 15:55:57 -0600
commit9ba04742771370f59740e32e11c5f3a1e6a1b70a (patch)
treec81c34dae2b3b1ea73801bf18a960265dc4207f7 /qtsharp/src/examples/tutorials
parent1a96c45b22d01378202d9dc7ed9c47acd30f966e (diff)
downloadtdebindings-9ba04742771370f59740e32e11c5f3a1e6a1b70a.tar.gz
tdebindings-9ba04742771370f59740e32e11c5f3a1e6a1b70a.zip
Initial TQt conversion
Diffstat (limited to 'qtsharp/src/examples/tutorials')
-rw-r--r--qtsharp/src/examples/tutorials/t1.cs4
-rw-r--r--qtsharp/src/examples/tutorials/t2.cs10
-rw-r--r--qtsharp/src/examples/tutorials/t3.cs12
-rw-r--r--qtsharp/src/examples/tutorials/t4.cs14
-rw-r--r--qtsharp/src/examples/tutorials/t5.cs18
-rw-r--r--qtsharp/src/examples/tutorials/t6.cs24
-rw-r--r--qtsharp/src/examples/tutorials/t7.cs26
7 files changed, 54 insertions, 54 deletions
diff --git a/qtsharp/src/examples/tutorials/t1.cs b/qtsharp/src/examples/tutorials/t1.cs
index 84c79d38..b5498d7a 100644
--- a/qtsharp/src/examples/tutorials/t1.cs
+++ b/qtsharp/src/examples/tutorials/t1.cs
@@ -9,9 +9,9 @@ public class Example {
public static int Main (String[] args)
{
- TQApplication a = new TQApplication (args);
+ TTQApplication a = new TTQApplication (args);
- TQPushButton hello = new TQPushButton ("Hello world!", null);
+ TTQPushButton hello = new TTQPushButton ("Hello world!", null);
// In C++, the second parameter is 0 (null pointer)
hello.Resize (100, 30);
diff --git a/qtsharp/src/examples/tutorials/t4.cs b/qtsharp/src/examples/tutorials/t4.cs
index a8884b92..68b3c26a 100644
--- a/qtsharp/src/examples/tutorials/t4.cs
+++ b/qtsharp/src/examples/tutorials/t4.cs
@@ -5,25 +5,25 @@
using System;
using Qt;
-public class MyWidget : TQWidget {
+public class MyWidget : TTQWidget {
- public MyWidget (TQWidget parent, String name) : base (parent, name)
+ public MyWidget (TTQWidget parent, String name) : base (parent, name)
// In C++, parent and name have default values of 0 (null pointer)
{
this.SetMinimumSize (200, 120);
this.SetMaximumSize (200, 120);
- TQPushButton quit = new TQPushButton ("Quit", this, "quit");
+ TTQPushButton quit = new TTQPushButton ("Quit", this, "quit");
quit.SetGeometry (62, 40, 75, 30);
- quit.SetFont (new TQFont ("Times", 18, TQFont.Weight.Bold) );
+ quit.SetFont (new TTQFont ("Times", 18, TTQFont.Weight.Bold) );
Connect ( quit, TQT_SIGNAL ("clicked()"), qApp, TQT_SLOT ("Quit()") );
- // In C++, qApp is a global variable. Here it's a property of the QObject
+ // In C++, qApp is a global variable. Here it's a property of the TQObject
// class, which we inherit, giving the same effect. We also inherit the
// static method connect().
}
- public MyWidget (TQWidget parent) : this (parent, "") {}
+ public MyWidget (TTQWidget parent) : this (parent, "") {}
public MyWidget () : this (null, "") {}
// Note that it was necessary to use an empty string ("")
// in the above. Using null does not work at runtime.
@@ -33,7 +33,7 @@ public class Example {
public static int Main (String[] args)
{
- TQApplication a = new TQApplication (args);
+ TTQApplication a = new TTQApplication (args);
MyWidget w = new MyWidget ();
w.SetGeometry (100, 100, 200, 120);
diff --git a/qtsharp/src/examples/tutorials/t5.cs b/qtsharp/src/examples/tutorials/t5.cs
index 0488969d..1430e6f3 100644
--- a/qtsharp/src/examples/tutorials/t5.cs
+++ b/qtsharp/src/examples/tutorials/t5.cs
@@ -5,19 +5,19 @@
using System;
using Qt;
-public class MyWidget : TQVBox {
+public class MyWidget : TTQVBox {
- public MyWidget (TQWidget parent, String name) : base (parent, name)
+ public MyWidget (TTQWidget parent, String name) : base (parent, name)
// In C++, parent and name have default values of 0 (null pointer)
{
- TQPushButton quit = new TQPushButton ("Quit", this, "quit");
- quit.SetFont ( new TQFont ("Times", 18, TQFont.Weight.Bold) );
+ TTQPushButton quit = new TTQPushButton ("Quit", this, "quit");
+ quit.SetFont ( new TTQFont ("Times", 18, TTQFont.Weight.Bold) );
- TQObject.Connect ( quit, TQT_SIGNAL ("clicked()"), qApp, TQT_SLOT ("Quit()") );
+ TTQObject.Connect ( quit, TQT_SIGNAL ("clicked()"), qApp, TQT_SLOT ("Quit()") );
- TQLCDNumber lcd = new TQLCDNumber (2, this, "lcd" );
+ TTQLCDNumber lcd = new TTQLCDNumber (2, this, "lcd" );
- TQSlider slider = new TQSlider (Orientation.Horizontal, this, "slider");
+ TTQSlider slider = new TTQSlider (Orientation.Horizontal, this, "slider");
// Note that Orientation is defined in the Qt class
slider.SetRange (0, 99);
slider.SetValue (0);
@@ -25,7 +25,7 @@ public class MyWidget : TQVBox {
Connect ( slider, TQT_SIGNAL ("valueChanged(int)"), lcd, TQT_SLOT ("Display(int)") );
}
- public MyWidget (TQWidget parent) : this (parent, "") {}
+ public MyWidget (TTQWidget parent) : this (parent, "") {}
public MyWidget () : this (null, "") {}
// Note that it was necessary to use an empty string ("")
// in the above. Using null does not work at runtime.
@@ -35,7 +35,7 @@ public class Example {
public static int Main (String[] args)
{
- TQApplication a = new TQApplication (args);
+ TTQApplication a = new TTQApplication (args);
MyWidget w = new MyWidget ();
a.SetMainWidget (w);
diff --git a/qtsharp/src/examples/tutorials/t6.cs b/qtsharp/src/examples/tutorials/t6.cs
index 6fee48e1..9912650b 100644
--- a/qtsharp/src/examples/tutorials/t6.cs
+++ b/qtsharp/src/examples/tutorials/t6.cs
@@ -5,42 +5,42 @@
using System;
using Qt;
-public class LCDRange : TQVBox {
+public class LCDRange : TTQVBox {
- public LCDRange (TQWidget parent, String name) : base (parent, name)
+ public LCDRange (TTQWidget parent, String name) : base (parent, name)
// In C++, parent and name have default values of 0 (null pointer)
{
- TQLCDNumber lcd = new TQLCDNumber (2, this, "lcd" );
- TQSlider slider = new TQSlider (Orientation.Horizontal, this, "slider");
+ TTQLCDNumber lcd = new TTQLCDNumber (2, this, "lcd" );
+ TTQSlider slider = new TTQSlider (Orientation.Horizontal, this, "slider");
slider.SetRange (0, 99);
slider.SetValue (0);
Connect ( slider, TQT_SIGNAL ("valueChanged(int)"), lcd, TQT_SLOT ("Display(int)") );
}
- public LCDRange (TQWidget parent) : this (parent, "") {}
+ public LCDRange (TTQWidget parent) : this (parent, "") {}
public LCDRange () : this (null, "") {}
// Note that it was necessary to use an empty string ("")
// in the above. Using null does not work at runtime.
}
-public class MyWidget : TQVBox {
+public class MyWidget : TTQVBox {
- MyWidget (TQWidget parent, String name) : base (parent, name)
+ MyWidget (TTQWidget parent, String name) : base (parent, name)
{
- TQPushButton quit = new TQPushButton ("Quit", this, "quit");
- quit.SetFont ( new TQFont ("Times", 18, TQFont.Weight.Bold) );
+ TTQPushButton quit = new TTQPushButton ("Quit", this, "quit");
+ quit.SetFont ( new TTQFont ("Times", 18, TTQFont.Weight.Bold) );
Connect ( quit, TQT_SIGNAL ("clicked()"), qApp, TQT_SLOT ("Quit()") );
- TQGrid grid = new TQGrid (4, this);
+ TTQGrid grid = new TTQGrid (4, this);
for ( int c =0; c < 4; c++ )
for ( int r = 0; r < 4; r++ )
new LCDRange (grid);
}
- public MyWidget (TQWidget parent) : this (parent, "") {}
+ public MyWidget (TTQWidget parent) : this (parent, "") {}
public MyWidget () : this (null, "") {}
}
@@ -48,7 +48,7 @@ public class Example {
public static int Main (String[] args)
{
- TQApplication a = new TQApplication (args);
+ TTQApplication a = new TTQApplication (args);
MyWidget w = new MyWidget ();
a.SetMainWidget (w);
diff --git a/qtsharp/src/examples/tutorials/t7.cs b/qtsharp/src/examples/tutorials/t7.cs
index e1891d26..ba9e758d 100644
--- a/qtsharp/src/examples/tutorials/t7.cs
+++ b/qtsharp/src/examples/tutorials/t7.cs
@@ -9,15 +9,15 @@ using System;
using Qt;
[DeclareQtSignal ("valueChanged(int)")]
-public class LCDRange : TQVBox {
+public class LCDRange : TTQVBox {
- TQSlider slider;
+ TTQSlider slider;
- public LCDRange (TQWidget parent, String name) : base (parent, name)
+ public LCDRange (TTQWidget parent, String name) : base (parent, name)
// In C++, parent and name have default values of 0 (null pointer)
{
- TQLCDNumber lcd = new TQLCDNumber (2, this, "lcd" );
- slider = new TQSlider (Orientation.Horizontal, this, "slider");
+ TTQLCDNumber lcd = new TTQLCDNumber (2, this, "lcd" );
+ slider = new TTQSlider (Orientation.Horizontal, this, "slider");
slider.SetRange (0, 99);
slider.SetValue (0);
@@ -25,7 +25,7 @@ public class LCDRange : TQVBox {
Connect ( slider, TQT_SIGNAL ("valueChanged(int)"), TQT_SIGNAL ("valueChanged(int)"));
}
- public LCDRange (TQWidget parent) : this (parent, "") {}
+ public LCDRange (TTQWidget parent) : this (parent, "") {}
public LCDRange () : this (null, "") {}
// Note that it was necessary to use an empty string ("")
// in the above. Using null does not work at runtime.
@@ -36,16 +36,16 @@ public class LCDRange : TQVBox {
}
}
-public class MyWidget : TQVBox {
+public class MyWidget : TTQVBox {
- MyWidget (TQWidget parent, String name) : base (parent, name)
+ MyWidget (TTQWidget parent, String name) : base (parent, name)
{
- TQPushButton quit = new TQPushButton ("Quit", this, "quit");
- quit.SetFont ( new TQFont ("Times", 18, TQFont.Weight.Bold) );
+ TTQPushButton quit = new TTQPushButton ("Quit", this, "quit");
+ quit.SetFont ( new TTQFont ("Times", 18, TTQFont.Weight.Bold) );
Connect ( quit, TQT_SIGNAL ("clicked()"), qApp, TQT_SLOT ("Quit()") );
- TQGrid grid = new TQGrid (4, this);
+ TTQGrid grid = new TTQGrid (4, this);
LCDRange previous = null;
@@ -60,7 +60,7 @@ public class MyWidget : TQVBox {
}
}
- public MyWidget (TQWidget parent) : this (parent, "") {}
+ public MyWidget (TTQWidget parent) : this (parent, "") {}
public MyWidget () : this (null, "") {}
}
@@ -68,7 +68,7 @@ public class Example {
public static int Main (String[] args)
{
- TQApplication a = new TQApplication (args);
+ TTQApplication a = new TTQApplication (args);
MyWidget w = new MyWidget ();
a.SetMainWidget (w);
diff --git a/qtsharp/src/examples/tutorials/t2.cs b/qtsharp/src/examples/tutorials/t2.cs
index 5dbe07d1..84af5a37 100644
--- a/qtsharp/src/examples/tutorials/t2.cs
+++ b/qtsharp/src/examples/tutorials/t2.cs
@@ -9,16 +9,16 @@ public class Example {
public static int Main (String[] args)
{
- TQApplication a = new TQApplication (args);
+ TTQApplication a = new TTQApplication (args);
- TQPushButton quit = new TQPushButton ("Quit", null);
+ TTQPushButton quit = new TTQPushButton ("Quit", null);
// In C++, the second parameter is 0 (null pointer)
quit.Resize (75, 30);
- quit.SetFont (new TQFont ("Times", 18, TQFont.Weight.Bold));
- // In C++, TQFont::Bold is sufficient
+ quit.SetFont (new TTQFont ("Times", 18, TTQFont.Weight.Bold));
+ // In C++, TTQFont::Bold is sufficient
- TQObject.Connect ( quit, QtSupport.TQT_SIGNAL ("clicked()"), a, QtSupport.TQT_SLOT ("Quit()") );
+ TTQObject.Connect ( quit, QtSupport.TQT_SIGNAL ("clicked()"), a, QtSupport.TQT_SLOT ("Quit()") );
// TQT_SIGNAL and TQT_SLOT are static functions of QtSupport
a.SetMainWidget (quit);
diff --git a/qtsharp/src/examples/tutorials/t3.cs b/qtsharp/src/examples/tutorials/t3.cs
index 26fece72..806c5184 100644
--- a/qtsharp/src/examples/tutorials/t3.cs
+++ b/qtsharp/src/examples/tutorials/t3.cs
@@ -10,16 +10,16 @@ public class Example {
public static int Main (String[] args)
{
- TQApplication a = new TQApplication (args);
+ TTQApplication a = new TTQApplication (args);
- TQVBox box = new TQVBox ();
+ TTQVBox box = new TTQVBox ();
box.Resize (200, 120);
- TQPushButton quit = new TQPushButton ("Quit", box);
- quit.SetFont (new TQFont ("Times", 18, TQFont.Weight.Bold));
- // In C++, TQFont::Bold is sufficient
+ TTQPushButton quit = new TTQPushButton ("Quit", box);
+ quit.SetFont (new TTQFont ("Times", 18, TTQFont.Weight.Bold));
+ // In C++, TTQFont::Bold is sufficient
- TQObject.Connect ( quit, QtSupport.TQT_SIGNAL ("clicked()"), a, QtSupport.TQT_SLOT ("Quit()") );
+ TTQObject.Connect ( quit, QtSupport.TQT_SIGNAL ("clicked()"), a, QtSupport.TQT_SLOT ("Quit()") );
// TQT_SIGNAL and TQT_SLOT are static functions of QtSupport
a.SetMainWidget (box);